@@ -145,6 +145,7 @@ char *lstname;		/* name of .lst file */
 char *logname;		/* name of .log file */
 int len;		/* length of lstname, logname */
 int v;			/* index to variables */
+double testd;           /* to check endianness */
 
 dap_param();
 dap_dapname = argv[0];
@@ -199,6 +200,17 @@ for (v = 0; v < dap_maxvar; v++)
 	dosave.do_str[v] = NULL;
 	}
 dap_ono = 0;
+testd = -2.0;
+if (!(*((int *) &testd)))
+	{
+	dap_dbllow = 0;
+	dap_dblhigh = 1;
+	}
+else
+	{
+	dap_dbllow = 1;
+	dap_dblhigh = 0;
+	}
 dap_main(argc, argv);
 return 0;
 }
@@ -1633,20 +1645,6 @@ if ((v = dap_varnum("_type_")) < 0)
 	}
 dap_obs[dap_ono].do_out[dap_obs[dap_ono].do_ovar++] = v;
 lineno[dap_ono] = 1;
-if (dap_dblhigh < 0)
-	{
-	testd = -2.0;
-	if (!(*((int *) &testd)))
-		{
-		dap_dbllow = 0;
-		dap_dblhigh = 1;
-		}
-	else
-		{
-		dap_dbllow = 1;
-		dap_dblhigh = 0;
-		}
-	}
 }
 
 /* Remove bracketed indices from explicit entry references
@@ -1822,20 +1820,6 @@ for (v = 0, first = 1; v < dap_obs[dap_ono].do_ovar; v++)
 	}
 dap_putc('\n', dap_out);
 dflush(dap_out);
-if (dap_dblhigh < 0)
-	{
-	testd = -2.0;
-	if (!(*((int *) &testd)))
-		{
-		dap_dbllow = 0;
-		dap_dblhigh = 1;
-		}
-	else
-		{
-		dap_dbllow = 1;
-		dap_dblhigh = 0;
-		}
-	}
 }
 
 void output()
