@@ -32,7 +32,7 @@ static void plot1(double x[], double y[], int nobs,
 	pict p[], pict a[], int pn, char style[],
 	double (*xfunct)(), double (*yfunct)(), int doaxes)
 {
-char *title0;
+static char *title0 = NULL;
 char *title1;
 int overlay;
 int n;
@@ -43,7 +43,8 @@ int t;
 double pictr;
 
 dap_swap();
-title0 = dap_malloc(dap_linelen + 1, "");
+if (!title0)
+	title0 = dap_malloc(dap_linelen + 1, "");
 title1 = dap_malloc(dap_linelen + 1, "");
 for (s = 0; style[s] == ' '; s++)
 	;
@@ -135,7 +136,6 @@ if (doaxes)
 					axspec, xfunct, yfunct, title1, PORTRAIT);
 	}
 dap_swap();
-dap_free(title0);
 dap_free(title1);
 }
 
@@ -561,7 +561,7 @@ dnobsp25 = ((double) nobs) + 0.25;
 for (r = 0, sum = 0.0, ss = 0.0, minx = 0.0, maxx = 0.0; r < nobs; r++)
 	{
 	dr = (double) r;
-	x[r] = invprobn((dr + 0.625) / dnobsp25);
+	x[r] = -npoint((dr + 0.625) / dnobsp25);
 	if (x[r] < minx)
 		minx = x[r];
 	if (x[r] > maxx)
@@ -1112,7 +1112,8 @@ dap_free(xname);
 return p;
 }
 
-pict *plotlinreg(char *fname, char *ylist, char *x1list, double level)
+pict *plotlinreg(char *fname, char *ylist, char *x1list,
+			char *marks, int nmarks, double level)
 {
 int varv[1];
 char *mnsname;
@@ -1120,7 +1121,9 @@ char *regname;
 char *srtarg;
 char *srtname;
 char *plotvars;
+char *plotmarks;
 pict *p;
+int pn;
 
 inset(fname);
 dap_list(ylist, varv, 1);	/* check that it's only 1 variable */
@@ -1134,32 +1137,41 @@ strcat(regname, ".reg");
 srtname = dap_malloc(strlen(regname) + 5, "");
 strcpy(srtname, regname);
 strcat(srtname, ".srt");
-means(fname, x1list, "STEP100", "");
-linreg(fname, ylist, "", x1list, "", mnsname, level);
+means(fname, x1list, "STEP100", marks);
+linreg(fname, ylist, "", x1list, marks, mnsname, level);
 dataset(fname, regname, "APPEND");
-srtarg = dap_malloc(strlen(x1list) + 8, "");
-strcpy(srtarg, "_type_ ");
+srtarg = dap_malloc(strlen(marks) + strlen(x1list) + 8, "");
+strcpy(srtarg, marks);
+strcat(srtarg, " _type_ ");
 strcat(srtarg, x1list);
 sort(regname, srtarg, "");
 plotvars = dap_malloc(strlen(x1list) + strlen(ylist) + 2, "");
 strcpy(plotvars, x1list);
 strcat(plotvars, " ");
 strcat(plotvars, ylist);
-p = plot(srtname, plotvars, "_type_", "obb", NULL, NULL, 4);
-strcpy(p[0].pict_type, "LINE");
-strcpy(p[2].pict_type, "LINE");
-strcpy(p[3].pict_type, "LINE");
-p[0].pict_dash = 4.0;
-p[3].pict_dash = 4.0;
+plotmarks = dap_malloc(strlen(marks) + strlen("_type_") + 2, "");
+strcpy(plotmarks, marks);
+strcat(plotmarks, " _type_");
+p = plot(srtname, plotvars, plotmarks, "o4bb", NULL, NULL, 4 * nmarks);
+for (pn = 0; pn < nmarks; pn++)
+	{
+	strcpy(p[4 * pn + 0].pict_type, "LINE");
+	strcpy(p[4 * pn + 2].pict_type, "LINE");
+	strcpy(p[4 * pn + 3].pict_type, "LINE");
+	p[4 * pn + 0].pict_dash = 4.0;
+	p[4 * pn + 3].pict_dash = 4.0;
+	}
 dap_free(mnsname);
 dap_free(regname);
 dap_free(srtarg);
 dap_free(srtname);
 dap_free(plotvars);
+dap_free(plotmarks);
 return p;
 }
 
-pict *plotlogreg(char *fname, char *yspec, char *x1list, int ngroups, double level)
+pict *plotlogreg(char *fname, char *yspec, char *x1list, int ngroups,
+					char *marks, int nmarks,  double level)
 {
 int varv[3];
 char *trlname;
@@ -1174,10 +1186,12 @@ char *lgrname;
 char *srtarg;
 char *srtname;
 char *plotvars;
+char *plotmarks;
 char *casevar;
 int c;
 int cs;
 pict *p;
+int pn;
 
 trlname = dap_malloc(strlen(fname) + 5, "");
 strcpy(trlname, fname);
@@ -1195,14 +1209,16 @@ lgrname = dap_malloc(strlen(fname) + 5, "");
 strcpy(lgrname, fname);
 strcat(lgrname, ".lgr");
 grparg = dap_malloc(strlen(x1list) + 14, "");
-grpvar = dap_malloc(strlen(x1list) + 2, "");
+grpvar = dap_malloc(strlen(marks) + strlen(x1list) + 3, "");
 casevar = dap_malloc(strlen(yspec) + 1, "");
 mnsarg = dap_malloc(strlen(yspec) + 12 + strlen(x1list), "");
-srtarg = dap_malloc(strlen(x1list) + 8, "");
+srtarg = dap_malloc(strlen(marks) + strlen(x1list) + 9, "");
 plotvars = dap_malloc(strlen(x1list) + strlen(yspec) + 2, "");
+plotmarks = dap_malloc(strlen(marks) + strlen("_type_") + 2, "");
 inset(fname);
 dap_list(x1list, varv, 1);	/* check that it's only 1 variable */
-strcpy(grpvar, "_");
+strcpy(grpvar, marks);
+strcat(grpvar, " _");
 strcat(grpvar, x1list);
 strcpy(casevar, yspec);
 for (cs = 0; casevar[cs] == ' '; cs++)
@@ -1228,7 +1244,7 @@ while (step())
 strcpy(grparg, x1list);
 sprintf(grparg + strlen(grparg), " %d COUNT", ngroups);
 
-group(trlname, grparg, "");
+group(trlname, grparg, marks);
 
 sort(grpname, grpvar, "");
 
@@ -1247,16 +1263,17 @@ while (step())
 	output();
 	}
 
-means(fname, x1list, "STEP100", "");
+means(fname, x1list, "STEP100", marks);
 
 strcpy(mnsname, fname);
 strcat(mnsname, ".mns");
 
-logreg(fname, yspec, "", x1list, "", mnsname, level);
+logreg(fname, yspec, "", x1list, marks, mnsname, level);
 
 dataset(grpname, lgrname, "APPEND");
 
-strcpy(srtarg, "_type_ ");
+strcpy(srtarg, marks);
+strcat(srtarg, " _type_ ");
 strcat(srtarg, x1list);
 
 sort(lgrname, srtarg, "");
@@ -1268,12 +1285,18 @@ strcpy(plotvars, x1list);
 strcat(plotvars, " ");
 strcat(plotvars, casevar);
 
-p = plot(srtname, plotvars, "_type_", "obb", NULL, NULL, 4);
-strcpy(p[0].pict_type, "LINE");
-strcpy(p[2].pict_type, "LINE");
-strcpy(p[3].pict_type, "LINE");
-p[0].pict_dash = 4.0;
-p[3].pict_dash = 4.0;
+strcpy(plotmarks, marks);
+strcat(plotmarks, " _type_");
+
+p = plot(srtname, plotvars, plotmarks, "o4bb", NULL, NULL, 4 * nmarks);
+for (pn = 0; pn < nmarks; pn ++)
+	{
+	strcpy(p[4 * pn + 0].pict_type, "LINE");
+	strcpy(p[4 * pn + 2].pict_type, "LINE");
+	strcpy(p[4 * pn + 3].pict_type, "LINE");
+	p[4 * pn + 0].pict_dash = 4.0;
+	p[4 * pn + 3].pict_dash = 4.0;
+	}
 dap_free(trlname);
 dap_free(grpname);
 dap_free(grparg);
@@ -1284,6 +1307,7 @@ dap_free(lgrname);
 dap_free(srtarg);
 dap_free(srtname);
 dap_free(plotvars);
+dap_free(plotmarks);
 dap_free(casevar);
 return p;
 }
