@@ -2121,12 +2121,12 @@ if (methn == TUKEY || methn == LSD)
 				strcpy(dap_obs[0].do_str[typen], "MINDIFF");
 				if (dfdown == dfup)
 					dap_obs[0].do_dbl[statn] =
-						invprobt(alpha / 2.0, edfi) *
+						tpoint(alpha / 2.0, edfi) *
 						sqrt(err * (effinvn[l1] + effinvn[l2]));
 				else
 					{
-					pdown = invprobt(alpha / 2.0, edfi);
-					pup = invprobt(alpha / 2.0, (int) dfup);
+					pdown = tpoint(alpha / 2.0, edfi);
+					pup = tpoint(alpha / 2.0, (int) dfup);
 					dap_obs[0].do_dbl[statn] =
 						(pdown +
 						 (dedfi - dfdown) / (dfup - dfdown) *
