@@ -62,7 +62,7 @@ double *f, *fch;
 int df;
 double ddf;
 double xi, xj;
-static double tpoint;
+static double tpt;
 int yn;
 int i, j;
 double *pred;
@@ -214,9 +214,9 @@ for (c = 0; c < ny; c++)
 		}
 	}
 if (level < 1.0)
-	tpoint = invprobt(0.5 * (1.0 - level), nobs - nx);
+	tpt = tpoint(0.5 * (1.0 - level), nobs - nx);
 else
-	tpoint = 0.0;
+	tpt = 0.0;
 dap_obs[0].do_dbl[varv[0]] = 1.0;
 if (xvarv[0] < 0)
 	{
@@ -254,15 +254,15 @@ while (matchmark(markv, xmarkv, nmark, level))
 	for (yn = 0; yn < ny; yn++)
 		dap_obs[0].do_dbl[varv[nx + yn]] = pred[yn];
 	output();
-	if (tpoint != 0.0)
+	if (tpt != 0.0)
 		{
 		strcpy(dap_obs[0].do_str[typen], "LOWER");
 		for (yn = 0; yn < ny; yn++)
-			dap_obs[0].do_dbl[varv[nx + yn]] = pred[yn] - tpoint * sqrt(sepred[yn]);
+			dap_obs[0].do_dbl[varv[nx + yn]] = pred[yn] - tpt * sqrt(sepred[yn]);
 		output();
 		strcpy(dap_obs[0].do_str[typen], "UPPER");
 		for (yn = 0; yn < ny; yn++)
-			dap_obs[0].do_dbl[varv[nx + yn]] = pred[yn] + tpoint * sqrt(sepred[yn]);
+			dap_obs[0].do_dbl[varv[nx + yn]] = pred[yn] + tpt * sqrt(sepred[yn]);
 		output();
 		}
 	if (xvarv[0] >= 0)
@@ -699,7 +699,7 @@ double *beta;
 int i, j;
 double tmp, tmp2;
 double loglike0, loglike1;
-static double npoint;
+static double npt;
 double xi, xj;
 double logit;
 double selogit;
@@ -755,9 +755,9 @@ for (i = 0; i < nx; i++)
 		0.00001 * ceil(100000.0 * probchisq(fabs(tmp2), 1)));
 	}
 if (fabs(level) < 1.0)
-	npoint = invprobn(0.5 * (1.0 + level));
+	npt = -npoint(0.5 * (1.0 - level));
 else
-	npoint = 0.0;
+	npt = 0.0;
 dap_obs[0].do_dbl[varv[0]] = 1.0;
 if (xvarv[0] < 0)
 	{
@@ -787,15 +787,15 @@ while (matchmark(markv, xmarkv, nmark, level))
 	strcpy(dap_obs[0].do_str[typen], "PRED");
 	dap_obs[0].do_dbl[varv[nx]] = 1.0 / (1.0 + exp(-logit));
         output();
-	if (npoint != 0.0)
+	if (npt != 0.0)
 		{
 		strcpy(dap_obs[0].do_str[typen], "LOWER");
 		dap_obs[0].do_dbl[varv[nx]] =
-				1.0 / (1.0 + exp(-logit + npoint * selogit));
+				1.0 / (1.0 + exp(-logit + npt * selogit));
 		output();
 		strcpy(dap_obs[0].do_str[typen], "UPPER");
 		dap_obs[0].do_dbl[varv[nx]] =
-				1.0 / (1.0 + exp(-logit - npoint * selogit));
+				1.0 / (1.0 + exp(-logit - npt * selogit));
 		output();
 		}
 	if (xvarv[0] >= 0)
