@@ -141,10 +141,10 @@ int dap_invert(double **mat, int nrc);
 double varnorm();
 double varunif();
 double probt(double t1, int di);
-double invprobchisq(double p, int df);
-double invprobf(double p, int numdf, int dendf);
-double invprobn(double p);
-double invprobt(double p, int in);
+double chisqpoint(double p, int df);
+double fpoint(double p, int numdf, int dendf);
+double npoint(double p);
+double tpoint(double p, int in);
 double probn(double z1);
 double probf(double f2, int id1, int id2);
 double probchisq(double x2, int df);
