@@ -27,17 +27,17 @@ while (--n >= 0)
 	dap_putc(((h >> (6 * n)) & 0x3f) + CHARBASE, dfp);
 }
 
-int dap_dblhigh = -1;
-int dap_dbllow = -1;
+int dap_dblhigh;
+int dap_dbllow;
 
 void dap_putdouble(double x, DFILE *dfp)
 {
-unsigned ix[2];
-unsigned sign;
-unsigned e;
+unsigned int ix[2];
+unsigned int sign;
+unsigned int e;
 
-ix[0] = *(((unsigned *) &x) + dap_dbllow);
-ix[1] = *(((unsigned *) &x) + dap_dblhigh);
+ix[0] = *(((unsigned int *) &x) + dap_dbllow);
+ix[1] = *(((unsigned int *) &x) + dap_dblhigh);
 if (!(ix[0] & 0x7fffffff) && !ix[1])
 	{
 	dap_putc('A', dfp);
@@ -76,9 +76,9 @@ else
 	}
 }
 
-static unsigned getnh(char s[], int n)
+static unsigned int getnh(char s[], int n)
 {
-unsigned h;
+unsigned int h;
 int i;
 
 for (h = ((s[0] - CHARBASE) & 0x3f), i = 1; i < n; i++)
@@ -89,9 +89,9 @@ return h;
 double dap_getdouble(char code[])
 {
 double x;
-unsigned ix[2];
-unsigned sign;
-unsigned e;
+unsigned int ix[2];
+unsigned int sign;
+unsigned int e;
 
 if (!strncmp(code, "A!!!!!!!!!!!", 12))
 	return 0.0;
@@ -113,8 +113,8 @@ if (sign)
 	}
 else
 	ix[1] = (ix[1] | (e << 20));
-*(((unsigned *) &x) + dap_dbllow) = ix[0];
-*(((unsigned *) &x) + dap_dblhigh) = ix[1];
+*(((unsigned int *) &x) + dap_dbllow) = ix[0];
+*(((unsigned int *) &x) + dap_dblhigh) = ix[1];
 return x;
 }
 
