@@ -78,7 +78,7 @@ else
 return c * dap_simp(&Tfun, atan(t1 / sqrt(dddi)), HALFPI, 1024);
 }
 
-double invprobn(double p)
+double npoint(double p)
 {
 static double a[4] = { 2.5066282, -18.6150006, 41.3911977, -25.4410605 };
 static double b[4] = { -8.4735109, 23.0833674, -21.0622410, 3.1308291 };
@@ -94,7 +94,7 @@ if (fabs(q) > 0.42)
 		r = 1.0 - p;
 	if (r <= 0.0)
 		{
-		fputs("invprobn: input not between 0 and 1\n", dap_log);
+		fputs("npoint: input not between 0 and 1\n", dap_log);
 		exit(1);
 		}
 	r = sqrt(-log(r));
@@ -109,17 +109,17 @@ else
 	x = q * (((a[3] * r + a[2]) * r + a[1]) * r + a[0]);
 	x0 = x / ((((b[3] * r + b[2]) * r + b[1]) * r + b[0]) * r + 1.0);
 	}
-return x0;
+return -x0;
 }
 
-double invprobt(double p, int df)
+double tpoint(double p, int df)
 {
 double pt0, pr0;
 double pt1, pr1;
 double pt2, pr2;
 
 pt2 = 0.0;	/* make compiler happy */
-pt0 = invprobn(p);
+pt0 = npoint(p);
 pr0 = probt(pt0, df);
 pt1 = 2.0 * pt0;
 pr2 = pr0;
@@ -215,7 +215,7 @@ while (s2 < s1 && (s2 * s2 / (s1 - s2) > 5.0e-11 / c))
 return c * s;
 }
 
-double invprobf(double p, int numdf, int dendf)
+double fpoint(double p, int numdf, int dendf)
 {
 double pt0, pr0;
 double pt1, pr1;
@@ -303,7 +303,7 @@ default:
 	}
 }
 
-double invprobchisq(double p, int df)
+double chisqpoint(double p, int df)
 {
 double pt0, pr0;
 double pt1, pr1;
